@@ -69,7 +69,7 @@
 #include "rtcvar.h"
 
 /* change to pass lwp rather than proc to driver entry points in 1.6V */
-#if __NetBSD_Version__ >= 106220000
+#if __NetBSD_Version__ == 106220000
 #define ENTRYARG	lwp
 #define LWP2PROC(l)	(l->l_proc)
 #else
@@ -77,17 +77,7 @@
 #define LWP2PROC(l)	(l)
 #endif
 
-/* forward compat */
-#ifndef LKM_DISPATCH
-/* old LKM code */
-#define LKM_DISPATCH(lkmtp, versioning, cmd, att, det, stat) \
-	DISPATCH(lkmtp, cmd, ver, att, det, stat)
-#define LKMLASTARG(x,y)	,y
-#else
-#define LKMLASTARG(x,y)	/* nothing */
-#endif
-
-int rtc_lkmentry(struct lkm_table *, int LKMLASTARG(0, int) );
+int rtc_lkmentry(struct lkm_table *, int, int);
 static int rtc_handle(struct lkm_table *, int);
 
 static int rtc_open(dev_t dev, int oflags, int devtype, struct ENTRYARG *);
@@ -113,7 +103,7 @@ MOD_DEV("linuxrtc", LM_DT_CHAR, -1, &rtc_dev)
 #endif
 
 int
-rtc_lkmentry(struct lkm_table *lkmtp, int cmd LKMLASTARG(0, int ver) )
+rtc_lkmentry(struct lkm_table *lkmtp, int cmd, int ver)
 {
 	LKM_DISPATCH(lkmtp, NULL, cmd, rtc_handle, rtc_handle, rtc_handle)
 }
