@@ -80,7 +80,7 @@
 #endif
 
 /* change to pass lwp rather than proc to driver entry points in 1.6V */
-#if __NetBSD_Version__ >= 106220000
+#if __NetBSD_Version__ == 106220000
 #define ENTRYARG	lwp
 #define LWP2PROC(l)	(l->l_proc)
 #else
@@ -88,16 +88,6 @@
 #define LWP2PROC(l)	(l)
 #endif
 
-/* forward compat */
-#ifndef LKM_DISPATCH
-/* old LKM code */
-#define LKM_DISPATCH(lkmtp, versioning, cmd, att, det, stat) \
-	DISPATCH(lkmtp, cmd, ver, att, det, stat)
-#define LKMLASTARG(x,y)	,y
-#else
-#define LKMLASTARG(x,y)	/* nothing */
-#endif
-
 #define FILECODE "F(300)"
 
 #include "x86.h"
@@ -126,7 +116,7 @@
 #ifndef _LKM
 void vmmonattach(int);
 #else
-int vmmon_lkmentry(struct lkm_table *, int LKMLASTARG(0, int) );
+int vmmon_lkmentry(struct lkm_table *, int, int);
 static int vmmon_handle(struct lkm_table *, int);
 #endif /* _LKM */
 
@@ -168,7 +158,7 @@ MOD_DEV("vmmon", LM_DT_CHAR, -1, &vmmon_cdevsw)
 #endif
 
 int
-vmmon_lkmentry(struct lkm_table *lkmtp, int cmd LKMLASTARG(0, int ver) )
+vmmon_lkmentry(struct lkm_table *lkmtp, int cmd, int ver)
 {
 	LKM_DISPATCH(lkmtp, NULL, cmd, vmmon_handle, vmmon_handle, vmmon_handle)
 }
