@@ -101,7 +101,7 @@ static int ether_ioctl(struct ifnet *, u_long, caddr_t);
 #endif
 
 /* change to pass lwp rather than proc to driver entry points in 1.6V */
-#if __NetBSD_Version__ >= 106220000
+#if __NetBSD_Version__ == 106220000
 #define ENTRYARG	lwp
 #define LWP2PROC(l)	(l->l_proc)
 #else
@@ -109,15 +109,6 @@ static int ether_ioctl(struct ifnet *, u_long, caddr_t);
 #define LWP2PROC(l)	(l)
 #endif
 
-/* forward compat */
-#ifndef LKM_DISPATCH
-/* old LKM code */
-#define LKM_DISPATCH(lkmtp, versioning, cmd, att, det, stat) \
-	DISPATCH(lkmtp, cmd, ver, att, det, stat)
-#define LKMLASTARG(x,y)	,y
-#else
-#define LKMLASTARG(x,y)	/* nothing */
-#endif
 extern struct vm_map *kernel_map;
 
 #define HUBDEBUG  if (hub_debug) printf
@@ -125,7 +116,7 @@ extern struct vm_map *kernel_map;
 #ifndef _LKM
 void vmnetattach(int);
 #else
-int vmnet_lkmentry(struct lkm_table *, int LKMLASTARG(0, int) );
+int vmnet_lkmentry(struct lkm_table *, int, int);
 #endif
 
 static int hub_open(dev_t dev, int oflags, int devtype, struct ENTRYARG *);
@@ -202,7 +193,7 @@ vmnetattach(int ndev)
 
 #else /* _LKM */
 int
-vmnet_lkmentry(struct lkm_table *lkmtp, int cmd LKMLASTARG(0, int ver) )
+vmnet_lkmentry(struct lkm_table *lkmtp, int cmd, int ver)
 {
 	LKM_DISPATCH(lkmtp, NULL, cmd, hub_handle, hub_handle, hub_handle)
 }
